@@ -4,8 +4,8 @@
    Add no modules to mathtools with intrapackage imports.
    Higher level modules with intrapackage imports should go elsewhere.'''
 
-from abjad.tools.imports.package_import import _package_import
+from abjad.tools.importtools._import_structured_package import _import_structured_package
 
-_package_import(__path__[0], globals( ))
+_import_structured_package(__path__[0], globals( ))
 
 
